==> vertx-stomp-3.4.0-sources.jar: io/vertx/groovy/ext/stomp/Destination_GroovyExtension.java <==
package io.vertx.groovy.ext.stomp;
public class Destination_GroovyExtension {
  public static io.vertx.ext.stomp.Destination dispatch(io.vertx.ext.stomp.Destination j_receiver, io.vertx.ext.stomp.StompServerConnection connection, java.util.Map<String, Object> frame) {
    io.vertx.groovy.ext.stomp.internal.ConversionHelper.wrap(j_receiver.dispatch(connection,
      frame != null ? new io.vertx.ext.stomp.Frame(io.vertx.groovy.ext.stomp.internal.ConversionHelper.toJsonObject(frame)) : null));
    return j_receiver;
  }
  public static io.vertx.ext.stomp.Destination subscribe(io.vertx.ext.stomp.Destination j_receiver, io.vertx.ext.stomp.StompServerConnection connection, java.util.Map<String, Object> frame) {
    io.vertx.groovy.ext.stomp.internal.ConversionHelper.wrap(j_receiver.subscribe(connection,
      frame != null ? new io.vertx.ext.stomp.Frame(io.vertx.groovy.ext.stomp.internal.ConversionHelper.toJsonObject(frame)) : null));
    return j_receiver;
  }
  public static boolean unsubscribe(io.vertx.ext.stomp.Destination j_receiver, io.vertx.ext.stomp.StompServerConnection connection, java.util.Map<String, Object> frame) {
    return j_receiver.unsubscribe(connection,
      frame != null ? new io.vertx.ext.stomp.Frame(io.vertx.groovy.ext.stomp.internal.ConversionHelper.toJsonObject(frame)) : null);
  }
  public static boolean ack(io.vertx.ext.stomp.Destination j_receiver, io.vertx.ext.stomp.StompServerConnection connection, java.util.Map<String, Object> frame) {
    return j_receiver.ack(connection,
      frame != null ? new io.vertx.ext.stomp.Frame(io.vertx.groovy.ext.stomp.internal.ConversionHelper.toJsonObject(frame)) : null);
  }
  public static boolean nack(io.vertx.ext.stomp.Destination j_receiver, io.vertx.ext.stomp.StompServerConnection connection, java.util.Map<String, Object> frame) {
    return j_receiver.nack(connection,
      frame != null ? new io.vertx.ext.stomp.Frame(io.vertx.groovy.ext.stomp.internal.ConversionHelper.toJsonObject(frame)) : null);
  }
}

==> vertx-stomp-3.5.4-sources.jar: io/vertx/groovy/ext/stomp/Destination_GroovyExtension.java <==
package io.vertx.groovy.ext.stomp;
public class Destination_GroovyExtension {
  public static io.vertx.ext.stomp.Destination dispatch(io.vertx.ext.stomp.Destination j_receiver, io.vertx.ext.stomp.StompServerConnection connection, java.util.Map<String, Object> frame) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.dispatch(connection,
      frame != null ? new io.vertx.ext.stomp.Frame(io.vertx.core.impl.ConversionHelper.toJsonObject(frame)) : null));
    return j_receiver;
  }
  public static io.vertx.ext.stomp.Destination subscribe(io.vertx.ext.stomp.Destination j_receiver, io.vertx.ext.stomp.StompServerConnection connection, java.util.Map<String, Object> frame) {
    io.vertx.core.impl.ConversionHelper.fromObject(j_receiver.subscribe(connection,
      frame != null ? new io.vertx.ext.stomp.Frame(io.vertx.core.impl.ConversionHelper.toJsonObject(frame)) : null));
    return j_receiver;
  }
  public static boolean unsubscribe(io.vertx.ext.stomp.Destination j_receiver, io.vertx.ext.stomp.StompServerConnection connection, java.util.Map<String, Object> frame) {
    return j_receiver.unsubscribe(connection,
      frame != null ? new io.vertx.ext.stomp.Frame(io.vertx.core.impl.ConversionHelper.toJsonObject(frame)) : null);
  }
  public static boolean ack(io.vertx.ext.stomp.Destination j_receiver, io.vertx.ext.stomp.StompServerConnection connection, java.util.Map<String, Object> frame) {
    return j_receiver.ack(connection,
      frame != null ? new io.vertx.ext.stomp.Frame(io.vertx.core.impl.ConversionHelper.toJsonObject(frame)) : null);
  }
  public static boolean nack(io.vertx.ext.stomp.Destination j_receiver, io.vertx.ext.stomp.StompServerConnection connection, java.util.Map<String, Object> frame) {
    return j_receiver.nack(connection,
      frame != null ? new io.vertx.ext.stomp.Frame(io.vertx.core.impl.ConversionHelper.toJsonObject(frame)) : null);
  }
}
